==> 7.6:test.zip: kibana/functional/page_objects/newsfeed_page.ts <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { FtrProviderContext } from '../ftr_provider_context';

export function NewsfeedPageProvider({ getService, getPageObjects }: FtrProviderContext) {
  const log = getService('log');
  const retry = getService('retry');
  const flyout = getService('flyout');
  const testSubjects = getService('testSubjects');
  const PageObjects = getPageObjects(['common']);

  class NewsfeedPage {
    async resetPage() {
      await PageObjects.common.navigateToUrl('home');
    }

    async closeNewsfeedPanel() {
      await flyout.ensureClosed('NewsfeedFlyout');
      log.debug('clickNewsfeed icon');
      await retry.waitFor('newsfeed flyout', async () => {
        if (await testSubjects.exists('NewsfeedFlyout')) {
          await testSubjects.click('NewsfeedFlyout > euiFlyoutCloseButton');
          return false;
        }
        return true;
      });
    }

    async openNewsfeedPanel() {
      log.debug('clickNewsfeed icon');
      return await testSubjects.exists('NewsfeedFlyout');
    }

    async getRedButtonSign() {
      return await testSubjects.exists('showBadgeNews');
    }

    async getNewsfeedList() {
      const list = await testSubjects.find('NewsfeedFlyout');
      const cells = await list.findAllByCssSelector('[data-test-subj="newsHeadAlert"]');

      const objects = [];
      for (const cell of cells) {
        objects.push(await cell.getVisibleText());
      }

      return objects;
    }

    async openNewsfeedEmptyPanel() {
      return await testSubjects.exists('emptyNewsfeed');
    }
  }

  return new NewsfeedPage();
}

==> 7.12:test.zip: kibana/functional/page_objects/newsfeed_page.ts <==
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

import { FtrProviderContext } from '../ftr_provider_context';

export function NewsfeedPageProvider({ getService, getPageObjects }: FtrProviderContext) {
  const log = getService('log');
  const find = getService('find');
  const retry = getService('retry');
  const flyout = getService('flyout');
  const testSubjects = getService('testSubjects');
  const PageObjects = getPageObjects(['common']);

  class NewsfeedPage {
    async resetPage() {
      await PageObjects.common.navigateToUrl('home', '', { useActualUrl: true });
    }

    async closeNewsfeedPanel() {
      await flyout.ensureClosed('NewsfeedFlyout');
      log.debug('clickNewsfeed icon');
      await retry.waitFor('newsfeed flyout', async () => {
        if (await testSubjects.exists('NewsfeedFlyout')) {
          await testSubjects.click('NewsfeedFlyout > euiFlyoutCloseButton');
          return false;
        }
        return true;
      });
    }

    async openNewsfeedPanel() {
      log.debug('clickNewsfeed icon');
      return await testSubjects.exists('NewsfeedFlyout');
    }

    async getRedButtonSign() {
      return await find.existsByCssSelector('.euiHeaderSectionItemButton__notification--dot');
    }

    async getNewsfeedList() {
      const list = await testSubjects.find('NewsfeedFlyout');
      const cells = await list.findAllByTestSubject('newsHeadAlert');

      const objects = [];
      for (const cell of cells) {
        objects.push(await cell.getVisibleText());
      }

      return objects;
    }

    async openNewsfeedEmptyPanel() {
      return await testSubjects.exists('emptyNewsfeed');
    }
  }

  return new NewsfeedPage();
}
